@@ -5,12 +5,12 @@
 # Tested on Fedora Core 3/5/8, Debian Etch, RHEL 5/6
 #
 # Cross toolchain and NSIS for Linux/i386/x86_64 can be fetched from
-#  http://www.ch-werner.de/xtools/crossmingw64-0.2-1.i386.rpm
-#  http://www.ch-werner.de/xtools/crossmingw64-0.2-1.x86_64.rpm
+#  http://www.ch-werner.de/xtools/crossmingw64-0.3-1.i386.rpm
+#  http://www.ch-werner.de/xtools/crossmingw64-0.3-1.x86_64.rpm
 #  http://www.ch-werner.de/xtools/nsis-2.37-1.i386.rpm
 # or
-#  http://www.ch-werner.de/xtools/crossmingw64-0.2.i386.tar.bz2
-#  http://www.ch-werner.de/xtools/crossmingw64-0.2.x86_64.tar.bz2
+#  http://www.ch-werner.de/xtools/crossmingw64-0.3.i386.tar.bz2
+#  http://www.ch-werner.de/xtools/crossmingw64-0.3.x86_64.tar.bz2
 #  http://www.ch-werner.de/xtools/nsis-2.37-1_i386.tar.gz
 
 # Some aspects of the build process can be controlled by shell variables:
@@ -25,9 +25,10 @@
 set -e
 
 VER2=2.8.17
-VER3=3.7.13
-VER3X=3071300
-TCCVER=0.9.25
+VER3=3.8.6
+VER3X=3080600
+VERZ=1.2.7
+TCCVER=0.9.26
 
 nov2=false
 if test -n "$NO_SQLITE2" ; then
@@ -69,12 +70,22 @@ if test -n "$WITH_SOURCES" ; then
     ADD_NSIS="$ADD_NSIS -DWITH_SOURCES"
 fi
 
+echo "=================="
+echo "Preparing zlib ..."
+echo "=================="
+test -r zlib-${VERZ}.tar.gz || \
+    wget -c http://zlib.net/zlib-${VERZ}.tar.gz || exit 1
+rm -rf zlib-${VERZ}
+tar xzf zlib-${VERZ}.tar.gz
+ln -sf zlib-${VERZ} zlib
+
 echo "===================="
 echo "Preparing sqlite ..."
 echo "===================="
 ( $nov2 && echo '*** skipped (NO_SQLITE2)' ) || true
 $nov2 || test -r sqlite-${VER2}.tar.gz || \
-    wget -c http://www.sqlite.org/sqlite-${VER2}.tar.gz
+    wget -c http://www.sqlite.org/sqlite-${VER2}.tar.gz \
+      --no-check-certificate
 $nov2 || test -r sqlite-${VER2}.tar.gz || exit 1
 
 $nov2 || rm -f sqlite
@@ -260,11 +271,13 @@ echo "====================="
 echo "Preparing sqlite3 ..."
 echo "====================="
 test -r sqlite-src-${VER3X}.zip || \
-    wget -c http://www.sqlite.org/sqlite-src-${VER3X}.zip
+    wget -c http://www.sqlite.org/2013/sqlite-src-${VER3X}.zip \
+      --no-check-certificate
 test -r sqlite-src-${VER3X}.zip || exit 1
 test -r extension-functions.c ||
     wget -O extension-functions.c -c \
-      'http://www.sqlite.org/contrib/download/extension-functions.c?get=25'
+      'http://www.sqlite.org/contrib/download/extension-functions.c?get=25' \
+      --no-check-certificate
 if test -r extension-functions.c ; then
   cp extension-functions.c extfunc.c
   patch < extfunc.patch
@@ -355,7 +368,13 @@ EOD
 
 # same but new module libshell.c
 cp -p sqlite3/src/shell.c sqlite3/src/libshell.c
-patch sqlite3/src/libshell.c <<'EOD'
+test "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
+  -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" -a "$VER3" != "3.7.16" \
+  -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" -a "$VER3" != "3.7.17" \
+  -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
+  && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
 +++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
 @@ -21,6 +21,10 @@
@@ -398,6 +417,99 @@ patch sqlite3/src/libshell.c <<'EOD'
  #else
 EOD
 
+test "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" \
+  && patch sqlite3/src/libshell.c <<'EOD'
+--- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
++++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
+@@ -21,6 +21,10 @@
+ #include <ctype.h>
+ #include <stdarg.h>
+
++#ifdef _WIN32
++# include <windows.h>
++#endif
++
+ #if !defined(_WIN32) && !defined(WIN32)
+ # include <signal.h>
+ # include <pwd.h>
+@@ -1774,7 +1778,7 @@
+   strcpy(continuePrompt,"   ...> ");
+ }
+ 
+-int main(int argc, char **argv){
++int sqlite3_main(int argc, char **argv){
+   char *zErrMsg = 0;
+   struct callback_data data;
+   const char *zInitFile = 0;
+@@ -1816,6 +1820,17 @@
+   if( i<argc ){
+     data.zDbFilename = argv[i++];
+   }else{
++#if defined(_WIN32) && !defined(__TINYC__)
++    static OPENFILENAME ofn;
++    static char zDbFn[1024];
++    ofn.lStructSize = sizeof(ofn);
++    ofn.lpstrFile = (LPTSTR) zDbFn;
++    ofn.nMaxFile = sizeof(zDbFn);
++    ofn.Flags = OFN_PATHMUSTEXIST | OFN_EXPLORER | OFN_NOCHANGEDIR;
++    if( GetOpenFileName(&ofn) ){
++      data.zDbFilename = zDbFn;
++    } else
++#endif
+ #ifndef SQLITE_OMIT_MEMORYDB
+     data.zDbFilename = ":memory:";
+ #else
+EOD
+
+test "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
+  -o "$VER3" = "3.7.16" -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" \
+  -o "$VER3" = "3.7.17" -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" \
+  -o "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
+  -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
+  -o "$VER3" = "3.8.6" \
+  && patch sqlite3/src/libshell.c <<'EOD'
+--- sqlite3.orig/src/libshell.c  2012-12-12 14:42:10.000000000 +0100
++++ sqlite3/src/libshell.c  2012-12-13 12:14:57.000000000 +0100
+@@ -36,6 +36,10 @@
+ #include <ctype.h>
+ #include <stdarg.h>
+ 
++#ifdef _WIN32
++#include <windows.h>
++#endif
++
+ #if !defined(_WIN32) && !defined(WIN32)
+ # include <signal.h>
+ # if !defined(__RTP__) && !defined(_WRS_KERNEL)
+@@ -2894,7 +2898,7 @@
+   return argv[i];
+ }
+ 
+-int main(int argc, char **argv){
++int sqlite3_main(int argc, char **argv){
+   char *zErrMsg = 0;
+   struct callback_data data;
+   const char *zInitFile = 0;
+@@ -2996,6 +3000,17 @@
+     }
+   }
+   if( data.zDbFilename==0 ){
++#if defined(_WIN32) && !defined(__TINYC__)
++    static OPENFILENAME ofn;
++    static char zDbFn[1024];
++    ofn.lStructSize = sizeof(ofn);
++    ofn.lpstrFile = (LPTSTR) zDbFn;
++    ofn.nMaxFile = sizeof(zDbFn);
++    ofn.Flags = OFN_PATHMUSTEXIST | OFN_EXPLORER | OFN_NOCHANGEDIR;
++    if( GetOpenFileName(&ofn) ){
++      data.zDbFilename = zDbFn;
++    } else
++#endif
+ #ifndef SQLITE_OMIT_MEMORYDB
+     data.zDbFilename = ":memory:";
+ #else
+EOD
+
 rm -f sqlite3/src/minshell.c
 touch sqlite3/src/minshell.c
 patch sqlite3/src/minshell.c <<'EOD'
@@ -463,6 +575,12 @@ test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
   -a "$VER3" != "3.7.7" -a "$VER3" != "3.7.7.1" -a "$VER3" != "3.7.8" \
   -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" -a "$VER3" != "3.7.11" \
   -a "$VER3" != "3.7.12" -a "$VER3" != "3.7.12.1" -a "$VER3" != "3.7.13" \
+  -a "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
+  -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" -a "$VER3" != "3.7.16" \
+  -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" -a "$VER3" != "3.7.17" \
+  -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
@@ -527,7 +645,7 @@ diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw-cross-build.sh,v 1.67 2012/06/24 09:36:50 chw Exp chw $
+ ** $Id: mingw-cross-build.sh,v 1.89 2014/09/17 02:07:03 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -682,6 +800,12 @@ test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.7.7" -a "$VER3" != "3.7.7.1" -a "$VER3" != "3.7.8" \
   -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" -a "$VER3" != "3.7.11" \
   -a "$VER3" != "3.7.12" -a "$VER3" != "3.7.12.1" -a "$VER3" != "3.7.13" \
+  -a "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
+  -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" -a "$VER3" != "3.7.16" \
+  -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" -a "$VER3" != "3.7.17" \
+  -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -767,7 +891,13 @@ patch -d sqlite3 -p1 <<'EOD'
 EOD
 test "$VER3" != "3.7.8" -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" \
   -a "$VER3" != "3.7.11" -a "$VER3" != "3.7.12" -a "$VER3" != "3.7.12.1" \
-  -a "$VER3" != "3.7.13" \
+  -a "$VER3" != "3.7.13" -a "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" \
+  -a "$VER3" != "3.7.15" -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" \
+  -a "$VER3" != "3.7.16" -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" \
+  -a "$VER3" != "3.7.17" -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" \
+  -a "$VER3" != "3.8.2" -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" \
+  -a "$VER3" != "3.8.4.1" -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" \
+  -a "$VER3" != "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_hash.c    2007-11-24 01:41:52.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_hash.c 2008-03-16 11:39:57.000000000 +0100
@@ -1106,7 +1236,10 @@ test "$VER3" = "3.6.17" -o "$VER3" = "3.6.18" -o "$VER3" = "3.6.19" \
        iColLen = ((zInput - z) + nStr + 1);
 EOD
 # patch: compile fix for rtree as extension module
-patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
+  && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2008-07-16 16:43:35.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2008-07-17 08:59:53.000000000 +0200
 @@ -2812,7 +2812,7 @@
@@ -1127,6 +1260,9 @@ test "$VER3" = "3.7.3" -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" \
   -o "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" -o "$VER3" = "3.7.11" \
   -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" -o "$VER3" = "3.7.13" \
+  -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" -o "$VER3" = "3.7.15" \
+  -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" -o "$VER3" = "3.7.16" \
+  -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" -o "$VER3" = "3.7.17" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2010-10-16 10:53:54.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2010-10-16 11:12:32.000000000 +0200
@@ -1155,6 +1291,7 @@ test "$VER3" = "3.7.6.1" -o "$VER3" = "3.7.6.2" -o "$VER3" = "3.7.6.3" \
   -o "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" -o "$VER3" = "3.7.11" \
   -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" -o "$VER3" = "3.7.13" \
+  -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/shell.c	2011-05-19 15:34:57.000000000 +0200
 +++ sqlite3/src/shell.c	2011-06-09 13:36:13.000000000 +0200
@@ -1172,6 +1309,12 @@ EOD
 test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" -o "$VER3" = "3.7.11" \
   -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" -o "$VER3" = "3.7.13" \
+  -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" -o "$VER3" = "3.7.15" \
+  -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" -o "$VER3" = "3.7.16" \
+  -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" -o "$VER3" = "3.7.17" \
+  -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
+  -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
+  -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_aux.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_aux.c	2011-06-25 06:44:08.000000000 +0200
@@ -1214,7 +1357,13 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" \
 EOD
 test "$VER3" = "3.7.8" -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" \
   -o "$VER3" = "3.7.11" -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" \
-  -o "$VER3" = "3.7.13" \
+  -o "$VER3" = "3.7.13" -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" \
+  -o "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
+  -o "$VER3" = "3.7.16" -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" \
+  -o "$VER3" = "3.7.17" -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" \
+  -o "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
+  -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
+  -o "$VER3" = "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c	2011-09-19 20:46:52.000000000 +0200
 +++ sqlite3/ext/fts3/fts3.c	2011-09-20 09:47:40.000000000 +0200
@@ -1242,6 +1391,12 @@ EOD
 test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" -o "$VER3" = "3.7.11" \
   -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" -o "$VER3" = "3.7.13" \
+  -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" -o "$VER3" = "3.7.15" \
+  -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" -o "$VER3" = "3.7.16" \
+  -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" -o "$VER3" = "3.7.17" \
+  -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
+  -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
+  -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_expr.c	2011-06-25 06:47:00.000000000 +0200
@@ -1360,7 +1515,8 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" \
  /*
 EOD
 test "$VER3" = "3.7.11" -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" \
-  -o "$VER3" = "3.7.13" \
+  -o "$VER3" = "3.7.13" -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" \
+  -o "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/sqlite3ext.h	2012-03-22 20:13:33.000000000 +0100
 +++ sqlite3/src/sqlite3ext.h	2012-03-22 20:13:57.000000000 +0100
@@ -1392,12 +1548,48 @@ test "$VER3" = "3.7.11" -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" \
  /*
 EOD
 
+test "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
+  -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
+  -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/src/loadext.c       2013-09-16 06:56:48.000000000 +0200
++++ sqlite3/src/loadext.c   2013-09-16 06:58:14.000000000 +0200
+@@ -495,7 +495,8 @@
+     memcpy(zAltEntry, "sqlite3_", 8);
+     for(iFile=ncFile-1; iFile>=0 && zFile[iFile]!='/'; iFile--){}
+     iFile++;
+-    if( sqlite3_strnicmp(zFile+iFile, "lib", 3)==0 ) iFile += 3;
++    if( sqlite3_strnicmp(zFile+iFile, "sqlite3_mod_", 12)==0 ) iFile += 12;
++    else if( sqlite3_strnicmp(zFile+iFile, "lib", 3)==0 ) iFile += 3;
+     for(iEntry=8; (c = zFile[iFile])!=0 && c!='.'; iFile++){
+       if( sqlite3Isalpha(c) ){
+         zAltEntry[iEntry++] = (char)sqlite3UpperToLower[(unsigned)c];
+EOD
+
+# revert FTS3 initializer name, would work when sqlite3_fts_init
+test "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
+  -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
+  -o "$VER3" = "3.8.6" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3.c      2014-03-26 10:26:28.000000000 +0100
++++ sqlite3/ext/fts3/fts3.c  2014-03-26 16:54:39.000000000 +0100
+@@ -5747,7 +5747,7 @@
+ #ifdef _WIN32
+ __declspec(dllexport)
+ #endif
+-int sqlite3_fts3_init(
++int sqlite3_extension_init(
+   sqlite3 *db, 
+   char **pzErrMsg,
+   const sqlite3_api_routines *pApi
+EOD
+
 echo "===================="
 echo "Preparing TinyCC ..."
 echo "===================="
 ( $notcc && echo '*** skipped (NO_TCCEXT)' ) || true
 $notcc || test -r tcc-${TCCVER}.tar.bz2 || \
-    wget -c http://download.savannah.nongnu.org/releases/tinycc/tcc-${TCCVER}.tar.bz2
+    wget -c http://download.savannah.gnu.org/releases/tinycc/tcc-${TCCVER}.tar.bz2
 $notcc || test -r tcc-${TCCVER}.tar.bz2 || exit 1
 
 $notcc || rm -rf tcc tcc-${TCCVER}
@@ -1424,6 +1616,12 @@ if test -n "$SQLITE_DLLS" ; then
     $nov2 || make -C sqlite -f ../mf-sqlite.mingw-cross sqlite.dll
 fi
 
+echo "================="
+echo "Building zlib ..."
+echo "================="
+
+make -C zlib -f ../mf-zlib.mingw-cross all
+
 echo "====================="
 echo "Building SQLite 3 ..."
 echo "====================="
@@ -1436,7 +1634,7 @@ if test -r sqlite3/sqlite3.c -a -f "$WITH_SEE" ; then
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_ACTIVATION_KEY=\\\"$SEE_KEY\\\""
     ADD_CFLAGS="$ADD_CFLAGS -DSEEEXT=\\\"$SEEEXT\\\""
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_API=static -DWIN32=1 -DNDEBUG=1 -DNO_TCL"
-    ADD_CFLAGS="$ADD_CFLAGS -DTHREADSAFE=1 -DSQLITE_OMIT_EXPLAIN=1"
+    ADD_CFLAGS="$ADD_CFLAGS -DTHREADSAFE=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_DLL=1 -DSQLITE_TRHEADSAFE=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_OS_WIN=1 -DSQLITE_ASCII=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_SOUNDEX=1"
@@ -1447,6 +1645,21 @@ if test -r sqlite3/sqlite3.c -a -f "$WITH_SEE" ; then
     unset SQLITE3_A10N_O
     unset SQLITE3_EXE
 fi
+if test "$VER3" = "3.8.6" ; then
+    patch sqlite3/sqlite3.c <<'EOD'
+--- sqlite3.orig/sqlite3.c      2014-09-14 15:02:38.000000000 +0200
++++ sqlite3/sqlite3.c   2014-09-14 15:03:02.000000000 +0200
+@@ -121057,7 +121057,7 @@
+ 
+ #if defined(_WIN32) || defined(WIN32)
+ # include <io.h>
+-/* # include <fcntl.h> */
++# include <fcntl.h>
+ #define isatty(h) _isatty(h)
+ #ifndef access
+ # define access(f,m) _access((f),(m))
+EOD
+fi
 if test -n "$SQLITE_DLLS" ; then
     make -C sqlite3 -f ../mf-sqlite3.mingw-cross sqlite3.dll
 fi
