@@ -23,8 +23,8 @@
 set -e
 
 VER2=2.8.17
-VER3=3.7.16.1
-VER3X=3071601
+VER3=3.8.6
+VER3X=3080600
 VERZ=1.2.7
 
 nov2=false
@@ -73,7 +73,8 @@ echo "Preparing sqlite ..."
 echo "===================="
 ( $nov2 && echo '*** skipped (NO_SQLITE2)' ) || true
 $nov2 || test -r sqlite-${VER2}.tar.gz || \
-    wget -c http://www.sqlite.org/sqlite-${VER2}.tar.gz
+    wget -c http://www.sqlite.org/sqlite-${VER2}.tar.gz \
+      --no-check-certificate
 $nov2 || test -r sqlite-${VER2}.tar.gz || exit 1
 
 $nov2 || rm -f sqlite
@@ -259,11 +260,13 @@ echo "====================="
 echo "Preparing sqlite3 ..."
 echo "====================="
 test -r sqlite-src-${VER3X}.zip || \
-    wget -c http://www.sqlite.org/sqlite-src-${VER3X}.zip
+    wget -c http://www.sqlite.org/2013/sqlite-src-${VER3X}.zip \
+      --no-check-certificate
 test -r sqlite-src-${VER3X}.zip || exit 1
 test -r extension-functions.c ||
     wget -O extension-functions.c -c \
-      'http://www.sqlite.org/contrib/download/extension-functions.c?get=25'
+      'http://www.sqlite.org/contrib/download/extension-functions.c?get=25' \
+      --no-check-certificate
 if test -r extension-functions.c ; then
   cp extension-functions.c extfunc.c
   patch < extfunc.patch
@@ -356,7 +359,10 @@ EOD
 cp -p sqlite3/src/shell.c sqlite3/src/libshell.c
 test "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
   -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" -a "$VER3" != "3.7.16" \
-  -a "$VER3" != "3.7.16.1" \
+  -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" -a "$VER3" != "3.7.17" \
+  -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
 +++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
@@ -445,7 +451,11 @@ test "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" \
 EOD
 
 test "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
-  -o "$VER3" = "3.7.16" -o "$VER3" = "3.7.16.1" \
+  -o "$VER3" = "3.7.16" -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" \
+  -o "$VER3" = "3.7.17" -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" \
+  -o "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
+  -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
+  -o "$VER3" = "3.8.6" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2012-12-12 14:42:10.000000000 +0100
 +++ sqlite3/src/libshell.c  2012-12-13 12:14:57.000000000 +0100
@@ -556,7 +566,10 @@ test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
   -a "$VER3" != "3.7.12" -a "$VER3" != "3.7.12.1" -a "$VER3" != "3.7.13" \
   -a "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
   -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" -a "$VER3" != "3.7.16" \
-  -a "$VER3" != "3.7.16.1" \
+  -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" -a "$VER3" != "3.7.17" \
+  -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
@@ -621,7 +634,7 @@ diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw64-cross-build.sh,v 1.37 2013/03/30 05:16:56 chw Exp chw $
+ ** $Id: mingw64-cross-build.sh,v 1.49 2014/09/17 02:07:03 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -778,7 +791,10 @@ test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.7.12" -a "$VER3" != "3.7.12.1" -a "$VER3" != "3.7.13" \
   -a "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
   -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" -a "$VER3" != "3.7.16" \
-  -a "$VER3" != "3.7.16.1" \
+  -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" -a "$VER3" != "3.7.17" \
+  -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -920,7 +936,11 @@ test "$VER3" != "3.7.8" -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" \
   -a "$VER3" != "3.7.11" -a "$VER3" != "3.7.12" -a "$VER3" != "3.7.12.1" \
   -a "$VER3" != "3.7.13" -a "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" \
   -a "$VER3" != "3.7.15" -a "$VER3" != "3.7.15.1" -a "$VER3" != "3.7.15.2" \
-  -a "$VER3" != "3.7.16" -a "$VER3" != "3.7.16.1" \
+  -a "$VER3" != "3.7.16" -a "$VER3" != "3.7.16.1" -a "$VER3" != "3.7.16.2" \
+  -a "$VER3" != "3.7.17" -a "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" \
+  -a "$VER3" != "3.8.2" -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" \
+  -a "$VER3" != "3.8.4.1" -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" \
+  -a "$VER3" != "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_hash.c    2007-11-24 01:41:52.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_hash.c 2008-03-16 11:39:57.000000000 +0100
@@ -1260,7 +1280,10 @@ test "$VER3" = "3.6.17" -o "$VER3" = "3.6.18" -o "$VER3" = "3.6.19" \
        iColLen = ((zInput - z) + nStr + 1);
 EOD
 # patch: compile fix for rtree as extension module
-patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
+  -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
+  -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
+  && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2008-07-16 16:43:35.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2008-07-17 08:59:53.000000000 +0200
 @@ -2812,7 +2812,7 @@
@@ -1283,7 +1306,7 @@ test "$VER3" = "3.7.3" -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" \
   -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" -o "$VER3" = "3.7.13" \
   -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" -o "$VER3" = "3.7.15" \
   -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" -o "$VER3" = "3.7.16" \
-  -o "$VER3" = "3.7.16.1" \
+  -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" -o "$VER3" = "3.7.17" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2010-10-16 10:53:54.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2010-10-16 11:12:32.000000000 +0200
@@ -1332,7 +1355,10 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" -o "$VER3" = "3.7.13" \
   -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" -o "$VER3" = "3.7.15" \
   -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" -o "$VER3" = "3.7.16" \
-  -o "$VER3" = "3.7.16.1" \
+  -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" -o "$VER3" = "3.7.17" \
+  -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
+  -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
+  -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_aux.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_aux.c	2011-06-25 06:44:08.000000000 +0200
@@ -1377,7 +1403,11 @@ test "$VER3" = "3.7.8" -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" \
   -o "$VER3" = "3.7.11" -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" \
   -o "$VER3" = "3.7.13" -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" \
   -o "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
-  -o "$VER3" = "3.7.16" -o "$VER3" = "3.7.16.1" \
+  -o "$VER3" = "3.7.16" -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" \
+  -o "$VER3" = "3.7.17" -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" \
+  -o "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
+  -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
+  -o "$VER3" = "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c	2011-09-19 20:46:52.000000000 +0200
 +++ sqlite3/ext/fts3/fts3.c	2011-09-20 09:47:40.000000000 +0200
@@ -1407,7 +1437,10 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" -o "$VER3" = "3.7.13" \
   -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" -o "$VER3" = "3.7.15" \
   -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" -o "$VER3" = "3.7.16" \
-  -o "$VER3" = "3.7.16.1" \
+  -o "$VER3" = "3.7.16.1" -o "$VER3" = "3.7.16.2" -o "$VER3" = "3.7.17" \
+  -o "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
+  -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
+  -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_expr.c	2011-06-25 06:47:00.000000000 +0200
@@ -1559,6 +1592,42 @@ test "$VER3" = "3.7.11" -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" \
  /*
 EOD
 
+test "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
+  -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
+  -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/src/loadext.c       2013-09-16 06:56:48.000000000 +0200
++++ sqlite3/src/loadext.c   2013-09-16 06:58:14.000000000 +0200
+@@ -495,7 +495,8 @@
+     memcpy(zAltEntry, "sqlite3_", 8);
+     for(iFile=ncFile-1; iFile>=0 && zFile[iFile]!='/'; iFile--){}
+     iFile++;
+-    if( sqlite3_strnicmp(zFile+iFile, "lib", 3)==0 ) iFile += 3;
++    if( sqlite3_strnicmp(zFile+iFile, "sqlite3_mod_", 12)==0 ) iFile += 12;
++    else if( sqlite3_strnicmp(zFile+iFile, "lib", 3)==0 ) iFile += 3;
+     for(iEntry=8; (c = zFile[iFile])!=0 && c!='.'; iFile++){
+       if( sqlite3Isalpha(c) ){
+         zAltEntry[iEntry++] = (char)sqlite3UpperToLower[(unsigned)c];
+EOD
+
+# revert FTS3 initializer name, would work when sqlite3_fts_init
+test "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
+  -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
+  -o "$VER3" = "3.8.6" \
+  && patch -d sqlite3 -p1 <<'EOD'
+--- sqlite3.orig/ext/fts3/fts3.c      2014-03-26 10:26:28.000000000 +0100
++++ sqlite3/ext/fts3/fts3.c  2014-03-26 16:54:39.000000000 +0100
+@@ -5747,7 +5747,7 @@
+ #ifdef _WIN32
+ __declspec(dllexport)
+ #endif
+-int sqlite3_fts3_init(
++int sqlite3_extension_init(
+   sqlite3 *db, 
+   char **pzErrMsg,
+   const sqlite3_api_routines *pApi
+EOD
+
 echo "========================"
 echo "Cleanup before build ..."
 echo "========================"
@@ -1607,7 +1676,7 @@ if test -r sqlite3/sqlite3.c -a -f "$WITH_SEE" ; then
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_ACTIVATION_KEY=\\\"$SEE_KEY\\\""
     ADD_CFLAGS="$ADD_CFLAGS -DSEEEXT=\\\"$SEEEXT\\\""
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_API=static -DWIN32=1 -DNDEBUG=1 -DNO_TCL"
-    ADD_CFLAGS="$ADD_CFLAGS -DTHREADSAFE=1 -DSQLITE_OMIT_EXPLAIN=1"
+    ADD_CFLAGS="$ADD_CFLAGS -DTHREADSAFE=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_DLL=1 -DSQLITE_THREADSAFE=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_OS_WIN=1 -DSQLITE_ASCII=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_SOUNDEX=1"
@@ -1618,6 +1687,21 @@ if test -r sqlite3/sqlite3.c -a -f "$WITH_SEE" ; then
     unset SQLITE3_A10N_O
     unset SQLITE3_EXE
 fi
+if test "$VER3" = "3.8.6" ; then
+    patch sqlite3/sqlite3.c <<'EOD'
+--- sqlite3.orig/sqlite3.c      2014-09-14 15:02:38.000000000 +0200
++++ sqlite3/sqlite3.c   2014-09-14 15:03:02.000000000 +0200
+@@ -121057,7 +121057,7 @@
+ 
+ #if defined(_WIN32) || defined(WIN32)
+ # include <io.h>
+-/* # include <fcntl.h> */
++# include <fcntl.h>
+ #define isatty(h) _isatty(h)
+ #ifndef access
+ # define access(f,m) _access((f),(m))
+EOD
+fi
 if test -n "$SQLITE_DLLS" ; then
     make -C sqlite3 -f ../mf-sqlite3.mingw64-cross sqlite3.dll
 fi
